@@ -26,17 +26,15 @@ def get_distribution_value_type(cell: Cell) -> DistributionCellValueType:
 
 
 class DistributionSheet(Sheet):
-    new_distribution_images: List[NewDistributionImage] = []
-    max_col: int = 3
-    start_col: int
-
-    distribution_data: DistributionData = DistributionData()
-
     def __init__(
             self,
             worksheet: Worksheet,
     ):
-        self.start_col = 0
+        self.new_distribution_images: List[NewDistributionImage] = []
+        self.distribution_data: DistributionData = DistributionData()
+
+        self.max_col: int = 3
+        self.start_col: int = 0
 
         super().__init__(
             worksheet=worksheet,
