@@ -47,7 +47,7 @@ class MotorcycleModelWorkbook:
             filename: Optional[str],
     ):
         self.motorcycle_model: Optional[MotorcycleModel]
-        self.new_distribution_images: Optional[List[NewDistributionImage]]
+        self.new_distribution_images: Optional[List[NewDistributionImage]] = None
 
         workbook: Workbook = load_workbook(filename=file)
 
